#ifndef _RTE_LINE_IN_H_
#define _RTE_LINE_IN_H_

#include "stdint.h"
#include "TYW_stdint.h"


uint8_t Get_LINE_IN_TRIP1(void);


_LINE_IN_TriggerLevel_ Get_Line_In_MaintainWarning(void);
_LINE_IN_TriggerLevel_ Get_Line_In_BrakeFluid(void);
_LINE_IN_TriggerLevel_ Get_Line_In_OTA_Switch(void);
_LINE_IN_TriggerLevel_ Get_Line_In_TRIP_Switch(void);
_LINE_IN_TriggerLevel_ Get_Line_In_SEATBELT_DR(void);
_LINE_IN_TriggerLevel_ Get_Line_In_TurnLeft(void);
_LINE_IN_TriggerLevel_ Get_Line_In_TurnRight(void);
_LINE_IN_TriggerLevel_ Get_Line_In_Hbeam(void);
_LINE_IN_TriggerLevel_ Get_Line_In_Lbeam(void);
_LINE_IN_TriggerLevel_ Get_Line_In_Position(void);
_LINE_IN_TriggerLevel_ Get_Line_In_RearFog(void);
_LINE_IN_TriggerLevel_ Get_Line_In_Daylight(void);
_LINE_IN_TriggerLevel_ Get_Line_In_Handbrake(void);
_LINE_IN_TriggerLevel_ Get_Line_In_SOC_CC(void);
_LINE_IN_TriggerLevel_ Get_Line_In_DoorOpen(void);
_LINE_IN_TriggerLevel_ Get_Line_In_Energy_Recovery(void);
_LINE_IN_TriggerLevel_ Get_Line_In_Energy_Recovery0(void);
void Gpio_Test(void);
#endif